@@ -47,6 +47,14 @@ function h2i_version
 	exit 0
 }
 
+function h2i_echo_result
+{
+	if [[ $? == 0 ]]
+	then echo "done"
+	else echo "error"
+	fi
+}
+
 TEMP=$(getopt -o "d:n:a:c:b:g:hv" \
 	      -l "dircategory:,programname:,author:,copyright:,bugreport:,generate:,help,version" -n "$H2I" -- "$@")
 eval set -- "$TEMP"
@@ -66,6 +74,12 @@ do
 	esac
 done
 
+if [[ -z $1 ]]
+then
+	echo "You must specify a command."
+	exit 1
+fi
+
 # capture output
 H2I_OUTPUT=$("$1" --help)
 
@@ -98,10 +112,6 @@ if [[ -z $H2I_INFO_COPYRIGHT ]]
 then H2I_INFO_COPYRIGHT="Insert copyright holder here"
 fi
 
-# get examples
-H2I_INFO_EXAMPLES="Insert your examples here"
-
-
 # get usage
 # Usage:
 #   or:
@@ -241,131 +251,156 @@ then H2I_INFO_BUGREPORT=$(h2i_bugreport "$H2I_OUTPUT")
 fi
 
 # generate the texi file
-printf "Creating ${H2I_INFO_PROGRAM_NAME}.texi in current directory..."
-cat > "${H2I_INFO_PROGRAM_NAME}.texi" <<EOF
-\input texinfo	@c -*-texinfo-*-
-@comment It was generated by help2info $H2I_VERSION.
-@comment %**start of header
-@setfilename ${H2I_INFO_PROGRAM_NAME}.info
-@include version.texi
-@settitle $H2I_INFO_PROGRAM_NAME @value{VERSION}
-@syncodeindex pg cp
-@comment %**end of header
-@copying
-This manual is for $H2I_INFO_PROGRAM_NAME
-(version @value{VERSION}, @value{UPDATED}),
-which is a program that $H2I_INFO_DESCRIPTION
+if [[ -a ${H2I_INFO_PROGRAM_NAME}.texi ]]
+then
+	echo "File ${H2I_INFO_PROGRAM_NAME}.texi exists."
+else
+	printf "Creating ${H2I_INFO_PROGRAM_NAME}.texi in current directory..."
+	cat > "${H2I_INFO_PROGRAM_NAME}.texi" <<-EOF
+	\input texinfo	@c -*-texinfo-*-
+	@comment It was generated by help2info $H2I_VERSION.
+	@comment %**start of header
+	@setfilename ${H2I_INFO_PROGRAM_NAME}.info
+	@include version.texi
+	@settitle $H2I_INFO_PROGRAM_NAME @value{VERSION}
+	@syncodeindex pg cp
+	@comment %**end of header
+	@copying
+	This manual is for $H2I_INFO_PROGRAM_NAME
+	(version @value{VERSION}, @value{UPDATED}),
+	which is a program that $H2I_INFO_DESCRIPTION
 
-Copyright @copyright{} $H2I_INFO_YEAR $H2I_INFO_COPYRIGHT
+	Copyright @copyright{} $H2I_INFO_YEAR $H2I_INFO_COPYRIGHT
 
-@quotation
-Permission is granted to copy, distribute, and/or modify this document
-under the terms of the GNU Free Documentation License, Version 1.2 or
-any later version published by the Free Software Foundation; with no
-Invariant Sections, with the Front-Cove Texts being ``A Manual,''
-and with the Back-Cover Texts as in (a) below. A copy of the
-license is included in the section entitled ``GNU Free Documentation
-License.''
+	@quotation
+	Permission is granted to copy, distribute, and/or modify this document
+	under the terms of the GNU Free Documentation License, Version 1.2 or
+	any later version published by the Free Software Foundation; with no
+	Invariant Sections, with the Front-Cove Texts being ``A Manual,''
+	and with the Back-Cover Texts as in (a) below. A copy of the
+	license is included in the section entitled ``GNU Free Documentation
+	License.''
 
-(a) The Back-Cover Text is: ``You have freedom to copy and modify
-this Manual, like GNU software.''
-@end quotation
-@end copying
-@dircategory $H2I_INFO_DIRCATEGORY
-@direntry
-* $H2I_INFO_PROGRAM_NAME: ($H2I_INFO_PROGRAM_NAME). $H2I_INFO_DESCRIPTION
-@end direntry
+	(a) The Back-Cover Text is: ``You have freedom to copy and modify
+	this Manual, like GNU software.''
+	@end quotation
+	@end copying
+	@dircategory $H2I_INFO_DIRCATEGORY
+	@direntry
+	* $H2I_INFO_PROGRAM_NAME: ($H2I_INFO_PROGRAM_NAME). $H2I_INFO_DESCRIPTION
+	@end direntry
 
-@titlepage
-@title $H2I_INFO_PROGRAM_NAME
-@subtitle for version @value{VERSION}, @value{UPDATED}
-@author $H2I_INFO_AUTHOR (@email{$H2I_INFO_BUGREPORT})
-@page
-@vskip 0pt plus 1filll
-@insertcopying
-@end titlepage
+	@titlepage
+	@title $H2I_INFO_PROGRAM_NAME
+	@subtitle for version @value{VERSION}, @value{UPDATED}
+	@author $H2I_INFO_AUTHOR (@email{$H2I_INFO_BUGREPORT})
+	@page
+	@vskip 0pt plus 1filll
+	@insertcopying
+	@end titlepage
 
-@contents
+	@contents
 
-@ifnottex
-@node Top
-@top $H2I_INFO_PROGRAM_NAME
-@insertcopying
-@end ifnottex
+	@ifnottex
+	@node Top
+	@top $H2I_INFO_PROGRAM_NAME
+	@insertcopying
+	@end ifnottex
 
-@menu
-* Introduction:: Introduction.
-* Invoking $H2I_INFO_PROGRAM_NAME::	Invocation.
-* Examples:: Some samples of use.
-* Reporting Bugs:: Reporting bugs
-* Copying This Manual:: The license for this documentation.
-@end menu
+	@menu
+	* Introduction:: Introduction.
+	* Invoking $H2I_INFO_PROGRAM_NAME::	Invocation.
+	* Examples:: Some samples of use.
+	* Reporting Bugs:: Reporting bugs
+	* Copying This Manual:: The license for this documentation.
+	@end menu
 
-@node Introduction 
-@chapter Introduction
-@pindex introduction
-@cindex introduction
-$H2I_INFO_DESCRIPTION
+	@node Introduction 
+	@chapter Introduction
+	@pindex introduction
+	@cindex introduction
+	$H2I_INFO_DESCRIPTION
 
-@node Invoking $H2I_INFO_PROGRAM_NAME
-@chapter Invoking $H2I_INFO_PROGRAM_NAME
-@pindex invoking
-@cindex invoking @command{$H2I_INFO_PROGRAM_NAME}
-@verbatim
-$H2I_INFO_USAGE
-@end verbatim
+	@node Invoking $H2I_INFO_PROGRAM_NAME
+	@chapter Invoking $H2I_INFO_PROGRAM_NAME
+	@pindex invoking
+	@cindex invoking @command{$H2I_INFO_PROGRAM_NAME}
+	@verbatim
+	$H2I_INFO_USAGE
+	@end verbatim
 
-@command{$H2I_INFO_PROGRAM_NAME} may be invoked with the following command-line options:
+	@command{$H2I_INFO_PROGRAM_NAME} may be invoked with the following command-line options:
 
-$H2I_INFO_OPTIONS
+	$H2I_INFO_OPTIONS
 
-@node Examples
-@chapter Examples
-@pindex examples
-@cindex examples
-$H2I_INFO_EXAMPLES
+	@node Examples
+	@chapter Examples
+	@pindex examples
+	@cindex examples
+	@enumerate
+	@item Insert your example here:
+	@example
+	Insert your command here
+	@end example
+	Insert your comments here
 
-@node Reporting Bugs
-@chapter Reporting Bugs
-@pindex bugs
-@cindex reporting bugs
-Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @dfn{$H2I_INFO_PROGRAM_NAME} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$H2I_INFO_PROGRAM_NAME --version} in the body of your report if at all possible.
+	@item Insert your example here:
+	@example
+	Insert your command here
+	@end example
+	Insert your comments here
+
+	@item Insert your example here:
+	@example
+	Insert your command here
+	@end example
+	Insert your comments here
+
+	@end enumerate
+
+	@node Reporting Bugs
+	@chapter Reporting Bugs
+	@pindex bugs
+	@cindex reporting bugs
+	Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @dfn{$H2I_INFO_PROGRAM_NAME} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$H2I_INFO_PROGRAM_NAME --version} in the body of your report if at all possible.
 
 
-@node Copying This Manual
+	@node Copying This Manual
 
-@appendix Copying This Manual
-@menu
-* GNU Free Documentation License::	License for copying this manual.
-@end menu
+	@appendix Copying This Manual
+	@menu
+	* GNU Free Documentation License::	License for copying this manual.
+	@end menu
 
-@include fdl.texi
+	@include fdl.texi
 
-@bye
-EOF
-if [[ $? == 0 ]]
-then echo "done"
-else echo "error"
+	@bye
+	EOF
+	h2i_echo_result
 fi
 
 #copy the fdl.texi file
-printf "Copying fdl.texi to current directory..."
-cp "$H2I_DATADIR/fdl.texi" .
-if [[ $? == 0 ]]
-then echo "done"
-else echo "error"
+if [[ -a fdl.texi ]]
+then
+	echo "File fdl.texi exists."
+else
+	printf "Copying fdl.texi to current directory..."
+	cp "$H2I_DATADIR/fdl.texi" .
+	h2i_echo_result
 fi
 
 if [[ -n $H2I_INFO_VERSION ]]
 then
-H2I_INFO_UPDATED=$(date '+%-e %B %Y')
-printf "Creating version.texi in current directory..."
-cat > "version.texi" <<EOF
-@set UPDATED $H2I_INFO_UPDATED
-@set VERSION $H2I_INFO_VERSION
-EOF
-if [[ $? == 0 ]]
-then echo "done"
-else echo "error"
-fi
+	if [[ -a version.texi ]]
+	then
+		echo "File version.texi exists."
+	else
+		H2I_INFO_UPDATED=$(date '+%-e %B %Y')
+		printf "Creating version.texi in current directory..."
+		cat > "version.texi" <<-EOF
+		@set UPDATED $H2I_INFO_UPDATED
+		@set VERSION $H2I_INFO_VERSION
+		EOF
+		h2i_echo_result
+	fi
 fi
